@@ -1,38 +1,5 @@
 package Algorithm::Dependency::Item;
 
-# Algorithm::Dependency::Item implements an object for a single item
-# in the database, with a unique id.
-
-use 5.005;
-use strict;
-use Algorithm::Dependency ();
-
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.0';
-}
-
-
-
-
-
-sub new {
-	my $class = shift;
-	my $id = shift or return undef;
-	my @depends = @_;
-
-	# Create the object
-	bless { id => $id, depends => \@depends }, $class;
-}
-
-# Get the values
-sub id { $_[0]->{id} }
-sub depends { @{$_[0]->{depends}} }
-
-1;
-
-__END__
-
 =pod
 
 =head1 NAME
@@ -48,23 +15,68 @@ their own source. ( See L<Algorithm::Dependency::Source> for details ).
 
 =head1 METHODS
 
+=cut
+
+use 5.005;
+use strict;
+use Algorithm::Dependency ();
+
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.105_01';
+}
+
+
+
+
+
+#####################################################################
+# Constructor
+
+=pod
+
 =head2 new $id, @depends
 
-The C<new> constructor takes as it's first argument the id ( name ) of the
+The C<new> constructor takes as its first argument the id ( name ) of the
 item, and any further arguments are assumed to be the ids of other items that
 this one depends on.
 
-Returns a new Algorithm::Dependency::Item on success, or C<undef> on error.
+Returns a new C<Algorithm::Dependency::Item> on success, or C<undef>
+on error.
+
+=cut
+
+sub new {
+	my $class = shift;
+	my $id    = (defined $_[0] and ! ref $_[0] and $_[0] ne '') ? shift : return undef;
+	bless { id => $id, depends => [ @_ ] }, $class;
+}
+
+=pod
 
 =head2 id
 
 The C<id> method returns the id of the item.
 
+=cut
+
+sub id { $_[0]->{id} }
+
+=pod
+
 =head2 depends
 
 The C<depends> method returns, as a list, the names of the other items that
 this item depends on.
 
+=cut
+
+sub depends { @{$_[0]->{depends}} }
+
+1;
+
+=pod
+
 =head1 SUPPORT
 
 For general comments, contact the author.
@@ -72,13 +84,11 @@ For general comments, contact the author.
 To file a bug against this module, in a way you can keep track of, see the
 CPAN bug tracking system.
 
-http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm%3A%3ADependency
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm-Dependency>
 
 =head1 AUTHOR
 
-    Adam Kennedy (Maintainer)
-    cpan@ali.as
-    http//ali.as/
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
 
 =head1 SEE ALSO
 
@@ -86,7 +96,8 @@ L<Algorithm::Dependency>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2004 Adam Kennedy. All rights reserved.
+Copyright (c) 2003 - 2005 Adam Kennedy.
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
