@@ -1,84 +1,5 @@
 package Algorithm::Dependency::Ordered;
 
-# This package implements a version of Algorithm::Dependency where the order
-# of the schedule is important.
-#
-# For example, when installing software packages, often their dependencies
-# not only need to be installed, but be installed in the correct order.
-#
-# The much more complex ->schedule method of this class takes these factors
-# into account. Please note that while circular dependencies are possible
-# and legal in unordered dependencies, they are a fatal error in ordered
-# dependencies. For that reason, the schedule method will return an error
-# if a circular dependency is found.
-
-use 5.005;
-use strict;
-use base 'Algorithm::Dependency';
-
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.0';
-}
-
-
-
-
-
-sub schedule {
-	my $self = shift;
-	my $source = $self->{source};
-	my @items = @_ or return undef;
-	return undef if grep { ! $source->item($_) } @items;
-
-	# The actual items to select will be the same as for the
-	# unordered version, and we can simplify the algortihm greatly
-	# by using the normal ->schedule method to get the starting list.
-	my $rv = $self->SUPER::schedule( @items );
-	my @queue = $rv ? @$rv : return undef;
-
-	# Get a working copy of the selected index
-	my %selected = %{ $self->{selected} };
-
-	# If at any time we check every item in the stack without finding
-	# a suitable candidate for addition to the schedule, we have found
-	# a circular reference error. We need to create a marker to track this.
-	my $error_marker = '';
-
-	# Create the schedule we will be filling.
-	my @schedule = ();
-
-	# Begin the processing loop
-	while ( my $id = shift @queue ) {
-		# Have we checked every item in the stack?
-		return undef if $id eq $error_marker;
-
-		# Are there any un-met dependencies
-		my $Item = $self->{source}->item( $id ) or return undef;
-		if ( grep { ! $selected{$_} } $Item->depends ) {
-			# Set the error market if not already
-			$error_marker = $id unless $error_marker;
-
-			# Add the id back to the end of the queue
-			push @queue, $id;
-			next;
-		}
-
-		# All dependencies have been met. Add the item to the schedule and
-		# to the selected index, and clear the error marker.
-		push @schedule, $id;
-		$selected{$id} = 1;
-		$error_marker = '';
-	}
-
-	# All items have been added
-	\@schedule;
-}
-
-1;
-
-__END__
-
 =pod
 
 =head1 NAME
@@ -99,20 +20,92 @@ order.
 
 For API details, see L<Algorithm::Dependency>.
 
+=cut
+
+use 5.005;
+use strict;
+use Algorithm::Dependency ();
+
+use vars qw{$VERSION @ISA};
+BEGIN {
+	$VERSION = '1.105_01';
+	@ISA     = 'Algorithm::Dependency';
+}
+
+
+
+
+
+sub schedule {
+	my $self   = shift;
+	my $source = $self->{source};
+	my @items  = @_ or return undef;
+	return undef if grep { ! $source->item($_) } @items;
+
+	# The actual items to select will be the same as for the unordered
+	# version, so we can simplify the algorithm greatly by using the
+	# normal unordered ->schedule method to get the starting list.
+	my $rv    = $self->SUPER::schedule( @items );
+	my @queue = $rv ? @$rv : return undef;
+
+	# Get a working copy of the selected index
+	my %selected = %{ $self->{selected} };
+
+	# If at any time we check every item in the stack without finding
+	# a suitable candidate for addition to the schedule, we have found
+	# a circular reference error. We need to create a marker to track this.
+	my $error_marker = '';
+
+	# Begin the processing loop
+	my @schedule = ();
+	while ( my $id = shift @queue ) {
+		# Have we checked every item in the stack?
+		return undef if $id eq $error_marker;
+
+		# Are there any un-met dependencies
+		my $Item    = $self->{source}->item($id) or return undef;
+		my @missing = grep { ! $selected{$_} } $Item->depends;
+
+		# Remove orphans if we are ignoring them
+		if ( $self->{ignore_orphans} ) {
+			@missing = grep { $self->{source}->item($_) } @missing;
+		}
+
+		if ( @missing ) {
+			# Set the error marker if not already
+			$error_marker = $id unless $error_marker;
+
+			# Add the id back to the end of the queue
+			push @queue, $id;
+			next;
+		}
+
+		# All dependencies have been met. Add the item to the schedule and
+		# to the selected index, and clear the error marker.
+		push @schedule, $id;
+		$selected{$id} = 1;
+		$error_marker  = '';
+	}
+
+	# All items have been added
+	\@schedule;
+}
+
+1;
+
+=pod
+
 =head1 SUPPORT
 
+Bugs should be submitted via the CPAN bug tracker, located at
+
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm-Dependency>
+
 For general comments, contact the author.
 
-To file a bug against this module, in a way you can keep track of, see the
-CPAN bug tracking system.
-
-http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm%3A%3ADependency
-
 =head1 AUTHOR
 
-    Adam Kennedy (Maintainer)
-    cpan@ali.as
-    http//ali.as/
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
 
 =head1 SEE ALSO
 
@@ -120,7 +113,8 @@ L<Algorithm::Dependency>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2004 Adam Kennedy. All rights reserved.
+Copyright (c) 2003 - 2005 Adam Kennedy.
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
